*Treatment optimisation for hepatitis C in the era of combination direct-acting*
*antiviral therapy: a systematic review and meta-analysis*
*CR Jones, BF Flower, B Simmons, E Barber, GS Cooke*
*Imperial College London*

*Load the "Data_CJones_2019" dataset (master sheet)*
*Import the first row as column labels*

*Drop the 4 real-world case-by-case individualisation studies*
*Centa 2017a, Peiffer 2018, Cento 2017b, Kileng 2018(summarised separately)*

*Create coded categorical variables from existing data + tidy labels*
encode design, generate(_des)
encode randomisation, generate(_random)
encode daacore, generate(_daa)
encode rbv, generate(_rbv)
encode broad_strategy, generate(_stratb)
encode theme, generate(_theme)
recode duration (3=1) (4=1) (6=2) (8=3) (12=4) (16=5) (24=6), generate(_dur)
label define _dur 1 "≤4 weeks" 2 "6 weeks" 3 "8 weeks" 4 "12 weeks" 5 "16 weeks" 6 "24 weeks"
label values _dur _dur
recode factorsn (1=1) (2=2) (3/5=3), generate(_factorsn)
label define _factorsn 1 "1 factor" 2 "2 factors" 3 "≥ 3 factors"
label values _factorsn _factorsn
encode clinfac, generate(_clinfac)
encode G3, generate(_g3)
recode _clinfac (1=2) (2=1) (3=3) (4=4)
label define _clinfac 1 "absent" 2 "TE" 3 "cirrhosis" 4 "cirrhosis + TE", replace
recode _des (1=3) (2=2) (3=1)
label define _des 1 "RCT" 2 "Quasi-experimental" 3 "Observational", replace
recode _random (1=2) (2=1)
label define _random 1 "Yes" 2 "No", replace
recode _stratb (1=2) (2=4) (3=1) (4=3)
label define _stratb 1 "Duration" 2 "Combination" 3 "Duration + Combination" 4 "Combination + Dose", replace
recode _theme (1=2) (2=1)
label define _theme 1 "Maintain SVR" 2 "Improve SVR", replace
recode _dur (1=4) (4=1)
label define _dur 1 "12 weeks" 2 "6 weeks" 3 "8 weeks" 4 "≤4 weeks" 5 "16 weeks" 6 "24 weeks", replace
recode _g3 (1=2) (2=1)
label define _g3 1 "Non-G3" 2 "G3", replace
encode strat_pers, generate(_strat_pers)
label define Pangenotypic 1 "Yes" 0 "No"
label values Pangenotypic Pangenotypic
label define categdur 0 "≥12 weeks" 1 "<12 weeks"
label values year categdur

label variable regimen "Regimen"
label variable trial "Trial"
label variable duration "Duration"
label variable svr12n "SVR12"
label variable totaln "Total"

*Perform meta-analysis of proportions - maintain SVR theme*
*Perform subgroup analyses*
*Use random effects model*
*Freeman-Tukey transformation with exact confidence intervals*
*Replace dp(1) with dp(3) for p value extraction*
*Export graph as EPS file*

metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall
label variable _ES "SVR12"
label variable _LCI "Lower CI"
label variable _UCI "Upper CI"
label variable _WT "Weight"
sort duration _ES
graph export example.eps, as(eps)

metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_rbv) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_daa) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_factorsn) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_clinfac) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_g3) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_strat_pers) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(Pangenotypic) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==1, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall

*perform metaregression for maintain SVR theme*

metareg _ES n, wsse(_seES)
xi: metareg _ES i._des, wsse(_seES)
xi: metareg _ES i._random, wsse(_seES)
xi: metareg _ES i._rbv, wsse(_seES)
xi: metareg _ES i._dur, wsse(_seES)
xi: metareg _ES i._factorsn, wsse(_seES)
xi: metareg _ES i._clinfac, wsse(_seES)
xi: metareg _ES i._g3, wsse(_seES)
xi: metareg _ES i._strat_pers, wsse(_seES)
xi: metareg _ES i.Pangenotypic, wsse(_seES)
metareg _ES male, wsse(_seES)
metareg _ES Meanage, wsse(_seES)
metareg _ES MeanBMI, wsse(_seES)
metareg _ES CCIL28B, wsse(_seES)
metareg _ES BLRNAlog10, wsse(_seES)
xi: metareg _ES i._daa, wsse(_seES)

xi: metareg _ES male i._des i._dur, wsse(_seES)

*Perform meta-analysis of proportions: improve SVR theme*
*Use random effects model*
*Freeman-Tukey transformation with exact confidence intervals*
*Replace dp(1) with dp(3) for p value extraction*
*Export graph as EPS file*

metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(58) texts(110) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox

label variable _ES "SVR12"
label variable _LCI "Lower CI"
label variable _UCI "Upper CI"
label variable _WT "Weight"
sort duration _ES
graph export Figure3.eps, as(eps)

metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_rbv) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_daa) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_factorsn) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_clinfac) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_g3) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_strat_pers) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(Pangenotypic) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop svr12n totaln if _theme==2, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall

*perform metaregression for improve SVR theme*
*omit BMI, IL28B and BL HCV RNA from metareg analysis for theme 2 improve svr as >30% data missing*

metareg _ES n, wsse(_seES)
xi: metareg _ES i._des, wsse(_seES)
xi: metareg _ES i._random, wsse(_seES)
xi: metareg _ES i._rbv, wsse(_seES)
xi: metareg _ES i._dur, wsse(_seES)
xi: metareg _ES i._factorsn, wsse(_seES)
xi: metareg _ES i._clinfac, wsse(_seES)
xi: metareg _ES i._g3, wsse(_seES)
xi: metareg _ES i._strat_pers, wsse(_seES)
xi: metareg _ES i.Pangenotypic, wsse(_seES)
metareg _ES male, wsse(_seES)
metareg _ES Meanage, wsse(_seES)
metareg _ES MeanBMI, wsse(_seES)
metareg _ES CCIL28B, wsse(_seES)
metareg _ES BLRNAlog10, wsse(_seES)
xi: metareg _ES i._daa, wsse(_seES)

xi: metareg _ES male i._des i._dur, wsse(_seES)

*G3*

metaprop svr12n totaln if _g3==2, random ftt cimethod(exact) by(Pangenotypic) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(74) texts(140) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox

*Per protocol analyses - repeat as above but using the PP SVR data*
*pp_svr and pp_total*

metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall

metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_rbv) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_daa) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_factorsn) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_clinfac) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_g3) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_strat_pers) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(Pangenotypic) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==1, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall

metareg _ES n, wsse(_seES)
xi: metareg _ES i._des, wsse(_seES)
xi: metareg _ES i._random, wsse(_seES)
xi: metareg _ES i._rbv, wsse(_seES)
xi: metareg _ES i._dur, wsse(_seES)
xi: metareg _ES i._factorsn, wsse(_seES)
xi: metareg _ES i._clinfac, wsse(_seES)
xi: metareg _ES i._g3, wsse(_seES)
xi: metareg _ES i._strat_pers, wsse(_seES)
xi: metareg _ES i.Pangenotypic, wsse(_seES)
metareg _ES male, wsse(_seES)
metareg _ES Meanage, wsse(_seES)
metareg _ES MeanBMI, wsse(_seES)
metareg _ES CCIL28B, wsse(_seES)
metareg _ES BLRNAlog10, wsse(_seES)
xi: metareg _ES i._daa, wsse(_seES)

metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall

metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_rbv) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_daa) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_factorsn) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_clinfac) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_g3) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_strat_pers) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(Pangenotypic) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall nograph
metaprop pp_svr pp_total if _theme==2, random ftt cimethod(exact) by(_dur) power(2) dp(1) label(namevar=trial,yearvar=regimen) lcols (trial regimen duration svr12n totaln) sortby(_ES) graphregion(color(white)) astext(76) texts(175) xlab(0,10,20,30,40,50,60,70,80,90,100) nobox nooverall
